[![Build Status](https://travis-ci.org/MartinThoma/nntoolkit.svg?branch=master)](https://travis-ci.org/MartinThoma/nntoolkit)
[![Coverage Status](https://img.shields.io/coveralls/MartinThoma/nntoolkit.svg)](https://coveralls.io/r/MartinThoma/nntoolkit?branch=master)
[![Documentation Status](http://img.shields.io/badge/docs-latest-brightgreen.svg)](http://pythonhosted.org/nntoolkit)

nntoolkit
=========

Toolkit to train neural networks

See [Deep Learning Tutorials](http://deeplearning.net/tutorial/).